Changelog
=========

2.1.2 (2018-10-22)
------------------

- Remove dependency to TurtledGazette.
  [cekk]


2.1.1 (2018-10-15)
------------------

- pypi publication.
  [cekk]

2.1.0 (2014-07-16)
------------------

- Now requires rt.lastmodifier, and publicly show dates [keul]

2.0.0 (2013-12-16)
------------------

Plone 4(.3) compatibility

- pyflakes cleanup [keul]
- Supported the "Site Administrator" role [keul]
- Added MANIFEST.in file [keul]
- Added Editor to add folder roles [andrea]
- Added dependency to PloneGazette and fixed permissions [andrea]

1.3.6 (2010-08-17)
------------------

- Support for z3c.autoinclude [keul]

1.3.5 (????-??-??)
------------------

- Fixed a bug in the review portlet when using "show all" [keul]

1.3.4 (13-01-2010)
------------------

- Sistemati i permessi per l'uso di CMFEditions

1.3.3 (11-09-2009)
------------------

- Sistemati permessi per usare correttamente ExternalEditor

1.3.2
-----

- Rimosso vecchio codice HTML della portlet che non rendeva la pagina valida [keul].

1.3.1
-----

- Modificato il template della portlet

1.3.0
-----

- Added propertiestool GS step, to handle reoles that manage keywords

1.2.0
-----

- full review list
- Fix grafici alla portlet

1.1.2
-----

- Fissati problemi (e logiche superate) alla portlet di revisione CCIAA.

1.1.1
-----

- aggiunte regole per il versionamento dei contenuti pubblicati e privati
- workflow usato anche per i file

1.1.0 - Unreleased
------------------

- Aggiunta dello stato privato per il camcom_public_workflow
- Rimosso codice non usato da Plone 2.5

1.0.1 - Unreleased
------------------

 - Fix minori e installazione in CCIAA di Treviso

1.0.0 - Unreleased
----------------

- Prima release

